@@ -21,17 +21,17 @@ def mk_dir(d):
     if not os.path.exists(d):
         os.makedirs(d)
 
+os_info = {  'ubuntu-18' : ('so', 'linux-x64'),
+             'ubuntu-20' : ('so', 'linux-x64'),
+             'glibc-2.31' : ('so', 'linux-x64'),
+             'x64-win' : ('dll', 'win-x64'),
+             'x86-win' : ('dll', 'win-x86'),
+             'osx' : ('dylib', 'osx-x64'),
+             'debian' : ('so', 'linux-x64') }
 
-os_info = {"z64-ubuntu-14" : ('so', 'linux-x64'),
-           'ubuntu-18' : ('so', 'linux-x64'),
-           'ubuntu-20' : ('so', 'linux-x64'),
-           'glibc-2.31' : ('so', 'linux-x64'),
-           'x64-win' : ('dll', 'win-x64'),
-           'x86-win' : ('dll', 'win-x86'),
-           'osx' : ('dylib', 'osx-x64'),
-           'debian' : ('so', 'linux-x64') }
+        
 
-def classify_package(f):
+def classify_package(f, arch):
     for os_name in os_info:
         if os_name in f:
             ext, dst = os_info[os_name]
@@ -45,7 +45,7 @@ def replace(src, dst):
     except:
         shutil.move(src, dst)
     
-def unpack(packages, symbols):
+def unpack(packages, symbols, arch):
     # unzip files in packages
     # out
     # +- runtimes
@@ -57,15 +57,15 @@ def unpack(packages, symbols):
     tmp = "tmp" if not symbols else "tmpsym"
     for f in os.listdir(packages):
         print(f)
-        if f.endswith(".zip") and classify_package(f):
-            os_name, package_dir, ext, dst = classify_package(f)
+        if f.endswith(".zip") and classify_package(f, arch):
+            os_name, package_dir, ext, dst = classify_package(f, arch)
             path = os.path.abspath(os.path.join(packages, f))
             zip_ref = zipfile.ZipFile(path, 'r')
             zip_ref.extract(f"{package_dir}/bin/libz3.{ext}", f"{tmp}")
             mk_dir(f"out/runtimes/{dst}/native")
             replace(f"{tmp}/{package_dir}/bin/libz3.{ext}", f"out/runtimes/{dst}/native/libz3.{ext}")            
-            if "x64-win" in f:
-                mk_dir("out/lib/netstandard1.4/")
+            if "x64-win" in f or "x86-win" in f:
+                mk_dir("out/lib/netstandard2.0/")
                 if symbols:
                     zip_ref.extract(f"{package_dir}/bin/libz3.pdb", f"{tmp}")
                     replace(f"{tmp}/{package_dir}/bin/libz3.pdb", f"out/runtimes/{dst}/native/libz3.pdb") 
@@ -74,7 +74,7 @@ def unpack(packages, symbols):
                     files += ["Microsoft.Z3.pdb", "Microsoft.Z3.xml"]
                 for b in files:
                     zip_ref.extract(f"{package_dir}/bin/{b}", f"{tmp}")
-                    replace(f"{tmp}/{package_dir}/bin/{b}", f"out/lib/netstandard1.4/{b}")
+                    replace(f"{tmp}/{package_dir}/bin/{b}", f"out/lib/netstandard2.0/{b}")
 
 def mk_targets(source_root):
     mk_dir("out/build")
@@ -85,11 +85,12 @@ def mk_icon(source_root):
     shutil.copy(f"{source_root}/resources/icon.jpg", "out/content/icon.jpg")
 
     
-def create_nuget_spec(version, repo, branch, commit, symbols):
+def create_nuget_spec(version, repo, branch, commit, symbols, arch):
+    arch = f".{arch}" if arch == "x86" else ""
     contents = """<?xml version="1.0" encoding="utf-8"?>
 <package xmlns="http://schemas.microsoft.com/packaging/2010/07/nuspec.xsd">
     <metadata>
-        <id>Microsoft.Z3</id>
+        <id>Microsoft.Z3{4}</id>
         <version>{0}</version>
         <authors>Microsoft</authors>
         <description>
@@ -107,34 +108,42 @@ Linux Dependencies:
         <requireLicenseAcceptance>true</requireLicenseAcceptance>
         <language>en</language>
         <dependencies>
-            <group targetFramework=".NETStandard1.4" />
+            <group targetFramework=".netstandard2.0" />
         </dependencies>
     </metadata>
-</package>""".format(version, repo, branch, commit)
+</package>""".format(version, repo, branch, commit, arch)
     print(contents)
     sym = "sym." if symbols else ""
-    file = f"out/Microsoft.Z3.{sym}nuspec"
+    file = f"out/Microsoft.Z3{arch}.{sym}nuspec"
     print(file)
     with open(file, 'w') as f:
         f.write(contents)
+
+class Env:
+    def __init__(self, argv):
+        self.packages = argv[1]
+        self.version = argv[2]
+        self.repo = argv[3]
+        self.branch = argv[4]
+        self.commit = argv[5]
+        self.source_root = argv[6]
+        self.symbols = False
+        self.arch = "x64"
+        if len(argv) > 7 and "symbols" == argv[7]:
+            self.symbols = True
+        if len(argv) > 8:
+            self.arch = argv[8]
+
+    def create(self):
+        mk_dir(self.packages)
+        unpack(self.packages, self.symbols, self.arch)
+        mk_targets(self.source_root)
+        mk_icon(self.source_root)
+        create_nuget_spec(self.version, self.repo, self.branch, self.commit, self.symbols, self.arch)
         
 def main():
-    packages = sys.argv[1]
-    version = sys.argv[2]
-    repo = sys.argv[3]
-    branch = sys.argv[4]
-    commit = sys.argv[5]
-    source_root = sys.argv[6]
-    symbols = False
-    if len(sys.argv) > 7:
-        print(sys.argv[7])
-    if len(sys.argv) > 7 and "symbols" == sys.argv[7]:
-        symbols = True
-    print(packages)
-    mk_dir(packages)
-    unpack(packages, symbols)
-    mk_targets(source_root)
-    mk_icon(source_root)
-    create_nuget_spec(version, repo, branch, commit, symbols)
+    env = Env(sys.argv)
+    print(env.packages)
+    env.create()
 
 main()
